@@ -9,8 +9,11 @@ const R_CallMethodDef callMethods[] = {
   {"BS_GetSubnets", (DL_FUNC) &BS_GetSubnets, 3},
   {"BS_ExtendSubnets", (DL_FUNC) &BS_ExtendSubnets, 3},
   {"ND_RatioDistribution", (DL_FUNC) &ND_RatioDistribution, 2},
+  {"ND_RatioDistributionParI", (DL_FUNC) &ND_RatioDistributionParI, 3},
+  {"ND_RatioDistributionParM", (DL_FUNC) &ND_RatioDistributionParM, 2},
   {"ND_RatioDistribution2", (DL_FUNC) &ND_RatioDistribution2, 3},
   {"ND_DiffRatioNet", (DL_FUNC) &ND_DiffRatioNet, 2},
+  {"ND_RatioVariance", (DL_FUNC) &ND_RatioVariance, 1},
   {NULL, NULL, 0}
 };
 
